..
    Copyright (C) 2022-2024 University of Münster.

    dnb-urn-service is free software; you can redistribute it and/or modify
    it under the terms of the MIT License; see LICENSE file for more details.

Authors
=======

Python API client wrapper for the DNB URN service API

- University of Münster <forschungsdaten@uni-muenster.de>
